==> skywalking-nodejs-src-0.3.0.tgz: src/proto/language-agent/CLRMetric_grpc_pb.d.ts <==
// package: 
// file: language-agent/CLRMetric.proto

/* tslint:disable */
/* eslint-disable */

import * as grpc from "grpc";
import * as language_agent_CLRMetric_pb from "../language-agent/CLRMetric_pb";
import * as common_Common_pb from "../common/Common_pb";

interface ICLRMetricReportServiceService extends grpc.ServiceDefinition<grpc.UntypedServiceImplementation> {
    collect: ICLRMetricReportServiceService_Icollect;
}

interface ICLRMetricReportServiceService_Icollect extends grpc.MethodDefinition<language_agent_CLRMetric_pb.CLRMetricCollection, common_Common_pb.Commands> {
    path: "/CLRMetricReportService/collect";
    requestStream: false;
    responseStream: false;
    requestSerialize: grpc.serialize<language_agent_CLRMetric_pb.CLRMetricCollection>;
    requestDeserialize: grpc.deserialize<language_agent_CLRMetric_pb.CLRMetricCollection>;
    responseSerialize: grpc.serialize<common_Common_pb.Commands>;
    responseDeserialize: grpc.deserialize<common_Common_pb.Commands>;
}

export const CLRMetricReportServiceService: ICLRMetricReportServiceService;

export interface ICLRMetricReportServiceServer {
    collect: grpc.handleUnaryCall<language_agent_CLRMetric_pb.CLRMetricCollection, common_Common_pb.Commands>;
}

export interface ICLRMetricReportServiceClient {
    collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}

export class CLRMetricReportServiceClient extends grpc.Client implements ICLRMetricReportServiceClient {
    constructor(address: string, credentials: grpc.ChannelCredentials, options?: object);
    public collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}

==> skywalking-nodejs-src-0.4.0.tgz: src/proto/language-agent/CLRMetric_grpc_pb.d.ts <==
// package: 
// file: language-agent/CLRMetric.proto

/* tslint:disable */
/* eslint-disable */

import * as grpc from "@grpc/grpc-js";
import * as language_agent_CLRMetric_pb from "../language-agent/CLRMetric_pb";
import * as common_Common_pb from "../common/Common_pb";

interface ICLRMetricReportServiceService extends grpc.ServiceDefinition<grpc.UntypedServiceImplementation> {
    collect: ICLRMetricReportServiceService_Icollect;
}

interface ICLRMetricReportServiceService_Icollect extends grpc.MethodDefinition<language_agent_CLRMetric_pb.CLRMetricCollection, common_Common_pb.Commands> {
    path: "/CLRMetricReportService/collect";
    requestStream: false;
    responseStream: false;
    requestSerialize: grpc.serialize<language_agent_CLRMetric_pb.CLRMetricCollection>;
    requestDeserialize: grpc.deserialize<language_agent_CLRMetric_pb.CLRMetricCollection>;
    responseSerialize: grpc.serialize<common_Common_pb.Commands>;
    responseDeserialize: grpc.deserialize<common_Common_pb.Commands>;
}

export const CLRMetricReportServiceService: ICLRMetricReportServiceService;

export interface ICLRMetricReportServiceServer extends grpc.UntypedServiceImplementation {
    collect: grpc.handleUnaryCall<language_agent_CLRMetric_pb.CLRMetricCollection, common_Common_pb.Commands>;
}

export interface ICLRMetricReportServiceClient {
    collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}

export class CLRMetricReportServiceClient extends grpc.Client implements ICLRMetricReportServiceClient {
    constructor(address: string, credentials: grpc.ChannelCredentials, options?: Partial<grpc.ClientOptions>);
    public collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
    public collect(request: language_agent_CLRMetric_pb.CLRMetricCollection, metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: common_Common_pb.Commands) => void): grpc.ClientUnaryCall;
}
